Researcher in economics often use databases that are sensitive, proprietary, or otherwise not publishable while respecting legal, contractual, and ethical constraints.
In more recent years, data editors and institutions have been working to nevertheless allow for ways to verify the computational reproducibility of research using such data. This involves a variety of actors: sending replicators to such institutions, requesting a credible third-party report, etc. No single solutions works uniformly.
The below database reports on successful verifications known to data editors, and their constraints. See definitions for key terms.
Search the database for any keyword in any field.
| Institution | Verification type | Research approval | Initiator | Verifier (if different) | Further info | Notes | Examples | Contributed by |
|---|---|---|---|---|---|---|---|---|
| CASD | Third-party certification | No | Journal | cascad | Link | Notes | Lars Vilhuber 2026-09-14 |
|
| World Bank | Institutional | Maybe | Author | DIME@World Bank | Link | Lars Vilhuber 2026-09-14 |
An independent third-party, not affiliated with either researcher or institution holding the data, conducts the research.
The institution holding the data conducts the verification. When the researcher is affiliated with the institution (staff), the verification will be considered internal, or possibly arms-length. When the researcher is not affilicated with the institution (example: research data centers with external researchers) the verification will be considered independent.
An arms-length replicator may be a research assistant employed by the researcher, but not previously involved in the research. Arms-length replicators are expected to follow the same protocols and standards as independent replicators, ensuring objectivity and minimizing potential biases.
An independent replicator is not affiliated with the researcher, and is normally sent or mandated by the journal’s data editor to conduct the research.
In certain cases, the researcher may need to provide approval for others to access or use their research project. In general, journals require researchers to assist journals in this process, but it may be more constraining for verifications conducted after publication.
The initiator is the person or entity who has to trigger the process. In some cases, the journal cannot, on its own, trigger the verification. In others, in particular with independent or third-party replicators, approval may not be needed by the researcher. Almost always, approval by the entity holding the data will be required, thus, that is not separately broken out in the table.
To download the entire database in CSV format, click here.
To add an entry, click here, and create a pull request.